# yamlito
[![Build Status](https://img.shields.io/github/workflow/status/hzanoli/yamlito/Build?style=flat-square)](https://github.com/hzanoli/yamlito/actions?query=workflow%3ABuild)
[![Codecov](https://img.shields.io/codecov/c/github/hzanoli/yamlito?style=flat-square)](https://codecov.io/gh/hzanoli/yamlito)
[![License](https://img.shields.io/github/license/hzanoli/yamlito?style=flat-square)](https://github.com/hzanoli/yamlito/blob/master/LICENSE)

Simple yaml config loader
